import sys
import zebra_day.print_mgr as zdpm

ip = sys.argv[1]

zpl_file = sys.argv[2]

zpld = zdpm.zpl()

zpl_string = ""

fh = open(zpl_file, 'r')
for i in fh:
    zpl_string += i.rstrip()


print(zpl_string)

zpld.print_raw_zpl(zpl_string , ip)

print('done!')



import socket

def send_sgd_command(ip, port, command):
    try:
        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
            s.connect((ip, port))
            s.sendall(command.encode())
            s.shutdown(socket.SHUT_WR)
            print(f"Command sent: {command}")
    except Exception as e:
        print(f"Error sending command: {e}")

# Replace with your printer's IP address
printer_ip = "192.168.1.29"  
printer_port = 9100

# SGD command to clear the WML file setting
clear_wml_file_command = "! U1 setvar \"wml.file\" \"XXX\"\r\n"

# Sending the command
send_sgd_command(printer_ip, printer_port, clear_wml_file_command)



import socket

def send_sgd_query(ip, port, command):
    response = ""
    try:
        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
            s.connect((ip, port))
            s.sendall(command.encode())
            s.shutdown(socket.SHUT_WR)
            while True:
                data = s.recv(1024)
                if not data:
                    break
                response += data.decode()
    except Exception as e:
        print(f"Error sending command: {e}")
    return response.strip()

# Replace with your printer's IP address
printer_ip = "192.168.1.29"
printer_port = 9100

# SGD commands to get the expected WML file and check if it exists
expected_wml_file_command = "! U1 getvar \"display.root_wml\"\r\n"
file_exists_command = lambda filename: f"! U1 do \"file.type\" \"{filename}\"\r\n"

# Sending commands and receiving responses
expected_wml_file = send_sgd_query(printer_ip, printer_port, expected_wml_file_command)
file_exists_response = send_sgd_query(printer_ip, printer_port, file_exists_command(expected_wml_file))

print(f"Expected WML File: {expected_wml_file}")
print(f"File Exists Response: {file_exists_response}")



import os

def test_creating_zpl_from_template():


    from zebra_day import print_mgr as zd
    zd_pm = zd.zpl()
    zd_pm.clear_printers_json()

    zpl = zd_pm.formulate_zpl(uid_barcode='TESTBC', alt_a='A', alt_b='B', alt_c='C', alt_d='D', alt_e='E', alt_f='F', label_zpl_style='tube_2inX1in')

    x = """^XA\n^FO235,20\n^BY1\n^B3N,N,40,N,N\n^FDTESTBC^FS\n^FO235,70\n^ADN,30,20\n^FDTESTBC^FS\n^FO235,115\n^ADN,25,12\n^FDA^FS\n^FO235,145\n^ADN,25,12\n^FDB^FS\n^FO70,180\n^FO235,170\n^ADN,30,20\n^FDC^FS\n^FO300,180\n^ADN,25,12\n^FDD^FS\n^FO490,180\n^ADN,25,12\n^FDE^FS\n^XZ"""

    assert x == zpl

def test_creating_a_png_of_label_zpl():

    import random
    from zebra_day import print_mgr as zd
    zd_pm = zd.zpl()
    zd_pm.clear_printers_json()
    zpl = zd_pm.formulate_zpl(uid_barcode='TESTBC', alt_a='A', alt_b='B', alt_c='C', alt_d='D', alt_e='E', alt_f='F', label_zpl_style='tube_2inX1in')    
    tmp_png = f"{os.path.dirname(zd.__file__)}/files/test_png_{random.randint(0,101010)}.png"
    tmp_full_png = zd_pm.generate_label_png(zpl_string=zpl, png_fn=tmp_png, relative=False)

    assert os.path.abspath(tmp_png) == os.path.abspath(tmp_full_png)


def test_printing_label():
    # Also prints a png, but uses the label printing path to do so.

    from zebra_day import print_mgr as zd
    zd_pm = zd.zpl()
    zd_pm.clear_printers_json()

    zd_pm.create_new_printers_json_with_single_test_printer()
    tmp_png_2 =  zd_pm.print_zpl(lab="scan-results", printer_name="Download-Label-png", uid_barcode='TESTBC', alt_a='A', alt_b='B', alt_c='C', alt_d='D', alt_e='E', alt_f='F', label_zpl_style="tube_2inX1in", client_ip='pkg', print_n=1, zpl_content=None)

    assert os.path.exists(tmp_png_2)


def test_probing_network_for_printers():
    # Expected to fail, testing if the top level png printer is added


    from zebra_day import print_mgr as zd
    zd_pm = zd.zpl()
    zd_pm.clear_printers_json()
    zd_pm.create_new_printers_json_with_single_test_printer()

    # Set the scan wait to FAR too short.  Good values are like 0.5+
    zd_pm.probe_zebra_printers_add_to_printers_json(ip_stub="192.168.1", scan_wait="0.01",lab="unit_test")

    # this just sees if the mechanise work... can't scan the network.
    assert 'unit_test' in zd_pm.printers['labs']



import os
import random

def test_printers_config_loading():
    
    from zebra_day import print_mgr as zd
    zd_pm = zd.zpl()
    assert 'labs' in zd_pm.printers.keys()


def test_printers_clear_reset():

    from zebra_day import print_mgr as zd
    zd_pm = zd.zpl()
    zd_pm.clear_printers_json()

    assert ('labs' in zd_pm.printers.keys() and len(zd_pm.printers['labs'].keys()) == 0)

    zd_pm.create_new_printers_json_with_single_test_printer()
    assert zd_pm.printers  == {'labs': {'scan-results': {'Download-Label-png': {'ip_address': 'dl_png',
                                                                                'label_zpl_styles': ['tube_2inX1in'],
                                                                                'print_method': 'generate png',
                                                                                'model': 'na',
                                                                                'serial': 'na',
                                                                                'arp_data': 'na'}}}}


def test_manipulating_printers_json():
    
    from zebra_day import print_mgr as zd
    zd_pm = zd.zpl()
    zd_pm.clear_printers_json()
    
    zd_pm.printers['labs']['test'] = {}

    tmp_json = f"etc/tmp_printers{random.randint(0,1000)}.json"
    
    zd_pm.save_printer_json(tmp_json)

    assert 'test' in zd_pm.printers['labs'].keys()
    assert zd_pm.printers_filename.removesuffix(tmp_json)
    assert os.path.exists(zd_pm.printers_filename)
        
    zd_pm.clear_printers_json(tmp_json)
    assert 'test' not in zd_pm.printers['labs'].keys()
    
    zd_pm.clear_printers_json(tmp_json)
    zd_pm.load_printer_json(tmp_json)
    zd_pm.printers['labs']['test'] = {}
    zd_pm.save_printer_json(tmp_json)

    assert zd_pm.printers['labs']['test'] == {}

    zd_pm.create_new_printers_json_with_single_test_printer()
    
    assert zd_pm.printers == {'labs': {'scan-results': {'Download-Label-png': {'ip_address': 'dl_png',
                                                                               'label_zpl_styles': ['tube_2inX1in'],
                                                                               'print_method': 'generate png',
                                                                               'model': 'na',
                                                                               'serial': 'na',
                                                                               'arp_data': 'na'}}}}


    os.system(f"rm {tmp_json}")
